@@ -226,7 +226,9 @@ class ConfigBox(VBox):
         for choice in choices:
             if type(choice) is str:
                 choice = [choice, choice]
-            if choice[1] == default:
+            if choice[1] == default and not has_entry:
+                # Do not add default label to editable dropdowns since this gets
+                # added to the actual value.
                 liststore.append([choice[0] + "  (default)", default])
                 self.tooltip_default = choice[0]
             else:
@@ -252,6 +254,7 @@ class ConfigBox(VBox):
                 combobox.set_active_id(default)
 
         combobox.connect('changed', self.on_combobox_change, option_name)
+        combobox.connect('scroll-event', self.on_combobox_scroll)
         label = Label(label)
         label.set_alignment(0.5, 0.5)
         combobox.set_valign(Gtk.Align.CENTER)
@@ -259,6 +262,12 @@ class ConfigBox(VBox):
         self.wrapper.pack_start(combobox, True, True, 0)
         self.option_widget = combobox
 
+    def on_combobox_scroll(self, combobox, event):
+        """Do not change options when scrolling
+        with cursor inside a ComboBox."""
+        combobox.stop_emission_by_name('scroll-event')
+        return False
+
     def on_combobox_change(self, combobox, option):
         """Action triggered on combobox 'changed' signal."""
         if combobox.get_has_entry():
