@@ -200,7 +200,7 @@ class ScriptInterpreter(CommandsMixin):
             else:
                 if not system.find_executable(dependency):
                     raise ScriptingError(
-                        "This installer requires %s on your system" % ' or '.join(dependency)
+                        "This installer requires %s on your system" % (dependency)
                     )
 
     def _check_dependency(self):
@@ -251,9 +251,13 @@ class ScriptInterpreter(CommandsMixin):
                 os.mkdir(self.cache_path)
 
             if self.target_path and self.should_create_target:
-                os.makedirs(self.target_path)
+                try:
+                    os.makedirs(self.target_path)
+                except PermissionError:
+                    raise ScriptingError("Lutris does not have necessary permissions to install to choosen game dir:", self.target_path)
                 self.reversion_data['created_main_dir'] = True
 
+
         if len(self.game_files) < len(self.files):
             logger.info(
                 "Downloading file %d of %d",
@@ -692,6 +696,7 @@ class ScriptInterpreter(CommandsMixin):
             "GAMEDIR": self.target_path,
             "CACHE": self.cache_path,
             "HOME": os.path.expanduser("~"),
+            "STEAM_DATA_DIR": steam.steam().steam_data_dir,
             "DISC": self.game_disc,
             "USER": os.getenv('USER'),
             "INPUT": self._get_last_user_input(),
